@@ -6,3 +6,5 @@ RECOMMENDS_TASK_CRONTAB = getattr(settings, 'RECOMMENDS_TASK_CRONTAB', {'hour':
 RECOMMENDS_CACHE_TEMPLATETAGS_TIMEOUT = getattr(settings, 'RECOMMENDS_CACHE_TEMPLATETAGS_TIMEOUT', 60)
 RECOMMENDS_STORAGE_BACKEND = getattr(settings, 'RECOMMENDS_STORAGE_BACKEND', 'recommends.storages.djangoorm.storage.DjangoOrmStorage')
 RECOMMENDS_STORAGE_DATABASE_NAME = getattr(settings, 'RECOMMENDS_STORAGE_DATABASE_NAME', 'recommends')
+RECOMMENDS_STORAGE_COMMIT_THRESHOLD = getattr(settings, 'RECOMMENDS_STORAGE_COMMIT_THRESHOLD', 1000)
+RECOMMENDS_LOGGER_NAME = getattr(settings, 'RECOMMENDS_LOGGER_NAME', 'recommends')
